@@ -9,6 +9,7 @@ OC.L10N.register(
     "Location:" : "Месцазнаходжанне:",
     "Duration:" : "Працягласць:",
     "Dates:" : "Даты:",
+    "Next week" : "На наступным тыдні",
     "Event" : "Падзея",
     "Today" : "Сёння",
     "Year" : "Год",
@@ -38,6 +39,7 @@ OC.L10N.register(
     "Close editor" : "Закрыць рэдактар",
     "General" : "Агульныя",
     "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
+    "Show weekends" : "Паказаць уік-энды",
     "Keyboard shortcuts" : "Спалучэнні клавіш",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
@@ -48,6 +50,7 @@ OC.L10N.register(
     "Update" : "Абнавіць",
     "Location" : "Месцазнаходжанне",
     "Description" : "Апісанне",
+    "Visibility" : "Бачнасць",
     "Duration" : "Працягласць",
     "Add" : "Дадаць",
     "Monday" : "Панядзелак",
@@ -59,31 +62,44 @@ OC.L10N.register(
     "Sunday" : "Нядзеля",
     "Your name" : "Ваша імя",
     "Back" : "Назад",
+    "Select conversation" : "Выберыце размову",
+    "on" : "укл.",
     "Notification" : "Апавяшчэнне",
     "Email" : "Электронная пошта",
     "seconds" : "с",
+    "Proceed" : "Працягнуць",
     "Upload from device" : "Запампаваць з прылады",
     "Delete file" : "Выдаліць файл",
     "{attendee} ({role})" : "{attendee} ({role})",
     "Out of office" : "Па-за офісам",
+    "Attendees:" : "Удзельнікі:",
+    "local time" : "мясцовы час",
     "Done" : "Гатова",
     "Busy" : "Заняты",
     "Unknown" : "Невядомы",
     "Accept" : "Прыняць",
     "Decline" : "Адхіліць",
+    "No attendees yet" : "Пакуль няма ўдзельнікаў",
+    "Attendees" : "Удзельнікі",
     "Remove group" : "Выдаліць групу",
+    "Remove attendee" : "Выдаліць удзельніка",
     "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
     "From" : "З",
     "To" : "Да",
     "never" : "ніколі",
     "Resources" : "Рэсурсы",
+    "Attendance required" : "Наведванне абавязковае",
+    "Attendance optional" : "Наведванне неабавязковае",
     "Remove participant" : "Выдаліць удзельніка",
     "Yes" : "Так",
     "No" : "Не",
     "Create" : "Ствараць",
+    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
     "Global" : "Глабальны",
     "Public calendars" : "Публічныя календары",
     "Invite" : "Запрасіць",
+    "Discard changes?" : "Адхіліць змены?",
+    "Untitled event" : "Падзея без назвы",
     "Close" : "Закрыць",
     "Selected" : "Выбрана",
     "Title" : "Загаловак",
@@ -93,6 +109,7 @@ OC.L10N.register(
     "90 min" : "90 хв",
     "Participants" : "Удзельнікі",
     "Submit" : "Адправіць",
+    "Meeting" : "Сустрэча",
     "Daily" : "Штодня",
     "Weekly" : "Штотыдзень",
     "Monthly" : "Штомесяц",
@@ -105,6 +122,7 @@ OC.L10N.register(
     "Untitled task" : "Задача без назвы",
     "%n more" : "%n яшчэ",
     "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
+    "Other" : "Іншае",
     "Status" : "Статус",
     "Confirmed" : "Пацверджана",
     "Canceled" : "Скасавана",
