@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Cheers!" : "শুভেচ্ছা!",
     "Calendar" : "দিনপঞ্জী",
+    "Location:" : "অবস্থান:",
     "Today" : "আজ",
     "Day" : "দিবস",
     "Week" : "সপ্তাহ",
@@ -15,13 +16,14 @@ OC.L10N.register(
     "Name" : "নাম",
     "Deleted" : "মুছে ফেলা",
     "Restore" : "ফিরিয়ে দাও",
-    "Hidden" : "লুকনো",
     "Share link" : "লিংক ভাগাভাগি করেন",
     "can edit" : "সম্পাদনা করতে পারবেন",
     "Save" : "সংরক্ষণ",
     "Cancel" : "বাতিল",
     "Automatic" : "স্বয়ংক্রিয়",
     "Actions" : "পদক্ষেপসমূহ",
+    "General" : "সাধারণ",
+    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
     "Update" : "পরিবর্ধন",
     "Location" : "অবস্থান",
     "Description" : "বিবরণ",
@@ -48,6 +50,8 @@ OC.L10N.register(
     "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Repeat" : "পূনঃসংঘটন",
     "never" : "কখনোই নয়",
+    "Yes" : "হ্যাঁ",
+    "No" : "না",
     "Subscribe" : "গ্রাহক হোন",
     "Personal" : "ব্যক্তিগত",
     "Edit event" : "ইভেন্ট সম্পাদনা করুন",
@@ -55,6 +59,7 @@ OC.L10N.register(
     "Daily" : "দৈনিক",
     "Weekly" : "সাপ্তাহিক",
     "second" : "সেকেন্ড",
-    "Other" : "অন্যান্য"
+    "Other" : "অন্যান্য",
+    "Hidden" : "লুকনো"
 },
 "nplurals=2; plural=(n != 1);");
