@@ -115,7 +115,6 @@ OC.L10N.register(
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
     "Shared calendars" : "Calendaris compartits",
     "Deck" : "Targetes",
-    "Hidden" : "Ocult",
     "Internal link" : "Enllaç intern",
     "A private link that can be used with external clients" : "Un enllaç privat que pot utilitzar-se amb clients externs",
     "Copy internal link" : "Copia l'enllaç intern",
@@ -166,6 +165,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["S'ha importat correctament %n esdeveniment","S'ha importat correctament %n esdeveniments"],
     "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
     "Automatic" : "Automàtic",
+    "Automatic ({timezone})" : "Automàtic ({timezone})",
     "New setting was not saved successfully." : "No s'ha desat correctament els nous paràmetres.",
     "Timezone" : "Fus horari",
     "Navigation" : "Navegació",
@@ -420,6 +420,7 @@ OC.L10N.register(
     "Yes" : "Sí",
     "No" : "No",
     "Maybe" : "Potser",
+    "None" : "Només una vegada",
     "Create" : "Crea",
     "from {formattedDate}" : "de {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
@@ -587,6 +588,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
     "Appointment not found" : "No s'ha trobat la cita",
     "User not found" : "No s'ha trobat l'usuari",
+    "Hidden" : "Ocult",
     "Automatic ({detected})" : "Automàtic ({detected})",
     "Shortcut overview" : "Descripció general de la drecera",
     "Enable simplified editor" : "Habilitar l'editor simplificat",
