@@ -115,7 +115,6 @@ OC.L10N.register(
     "Could not update calendar order." : "No se pudo actualizar el orden del calendario.",
     "Shared calendars" : "Compartir calendarios",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Internal link" : "Enlace interno",
     "A private link that can be used with external clients" : "Un enlace privado que se puede usar con clientes externos",
     "Copy internal link" : "Copiar enlace interno",
@@ -166,7 +165,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó exitosamente %n evento","Se importaron exitosamente %n eventos","Se importaron exitosamente %n eventos"],
     "Import partially failed. Imported {accepted} out of {total}." : "La importación falló parcialmente. Se importaron {accepted} de {total}.",
     "Automatic" : "Automático",
-    "Automatic ({detected})" : "Automático ({detected})",
+    "Automatic ({timezone})" : "({timezone}) automática",
     "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
     "Timezone" : "Zona horaria",
     "Navigation" : "Navegación",
@@ -400,6 +399,7 @@ OC.L10N.register(
     "Public calendar does not exist" : "El calendario público no existe",
     "Maybe the share was deleted or has expired?" : "¿Quizá el recurso compartido fue eliminado o caducó?",
     "Maybe" : "Tal vez",
+    "None" : "Ninguno",
     "Create" : "Crear",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "hasta {formattedDate}",
@@ -553,6 +553,8 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto",
+    "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Vista general de atajos",
     "Enable simplified editor" : "Habilitar el editor simplificado",
     "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
