@@ -116,7 +116,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Ezin da egutegi-eskaera eguneratu.",
     "Shared calendars" : "Partekatutako egutegiak",
     "Deck" : "Deck",
-    "Hidden" : "Ezkutuan",
     "Internal link" : "Barneko esteka",
     "A private link that can be used with external clients" : "Kanpoko bezeroengatik erabili ahal den esteka pribatua",
     "Copy internal link" : "Kopiatu barne-esteka",
@@ -168,7 +167,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n gertaera behar bezala inportatu dira","%n gertaera behar bezala inportatu dira"],
     "Import partially failed. Imported {accepted} out of {total}." : "Inportazioak huts egin du hein batean. Guztira {total} ziren, {accepted} inportatu dira.",
     "Automatic" : "Automatikoa",
-    "Automatic ({detected})" : "Automatikoa ({detected})",
+    "Automatic ({timezone})" : "Automatikoa ({timezone})",
     "New setting was not saved successfully." : "Ezarpen berria ez da behar bezala gorde.",
     "Timezone" : "Ordu-zona",
     "Navigation" : "Nabigazioa",
@@ -407,6 +406,7 @@ OC.L10N.register(
     "Yes" : "Bai",
     "No" : "Ez",
     "Maybe" : "Agian",
+    "None" : "Bat ere ez",
     "Create" : "Sortu",
     "from {formattedDate}" : "{formattedDate}tik ",
     "to {formattedDate}" : "{formattedDate} arte ",
@@ -563,6 +563,8 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Errore bat gertatu da PROPFIND errore bat analizatzean",
     "Appointment not found" : "Ez da hitzordua aurkitu",
     "User not found" : "Ez da erabiltzailea aurkitu",
+    "Hidden" : "Ezkutuan",
+    "Automatic ({detected})" : "Automatikoa ({detected})",
     "Shortcut overview" : "Lasterbideen informazio orokorra",
     "Enable simplified editor" : "Gaitu editore sinplifikatua",
     "Limit the number of events displayed in the monthly view" : "Mugatu hileroko ikuspegian bistaratzen diren gertaeren kopurua",
