@@ -115,7 +115,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Gat ekki uppfært röð dagatalanna.",
     "Shared calendars" : "Sameiginleg dagatöl",
     "Deck" : "Deck-spjaldaforrit",
-    "Hidden" : "Falinn",
     "Internal link" : "Innri tengill",
     "A private link that can be used with external clients" : "Einkatengill sem hægt er að nota með öðrum forritum",
     "Copy internal link" : "Afrita innri tengil",
@@ -166,8 +165,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Það tókst að flytja inn %n atburð","Það tókst að flytja inn %n atburði"],
     "Import partially failed. Imported {accepted} out of {total}." : "Innflutningur mistókst að hluta. Flutti inn {accepted} af {total}.",
     "Automatic" : "Sjálfvirkt",
-    "Automatic ({detected})" : "Sjálfvirkt ({detected})",
+    "Automatic ({timezone})" : "Sjálfvirkt ({timezone})",
     "New setting was not saved successfully." : "Ekki tókst að vista nýju stillinguna.",
+    "Timezone" : "Tímabelti",
     "Navigation" : "Yfirsýn",
     "Previous period" : "Fyrra tímabil",
     "Next period" : "Næsta tímabil",
@@ -185,7 +185,6 @@ OC.L10N.register(
     "Save edited event" : "Vista breyttan atburð",
     "Delete edited event" : "Eyða breyttum atburði",
     "Duplicate event" : "Tvítaka atburð",
-    "Shortcut overview" : "Yfirlit flýtilykla",
     "or" : "eða",
     "Calendar settings" : "Stillingar dagatals",
     "At event start" : "Við upphaf atburðar",
@@ -193,19 +192,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Mistókst að vista sjálfgefið dagatal",
     "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
     "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
-    "Enable birthday calendar" : "Virkja fæðingardagatal",
-    "Show tasks in calendar" : "Sýna verkefni í dagatali",
-    "Enable simplified editor" : "Virkja einfaldaðan ritil",
-    "Limit the number of events displayed in the monthly view" : "Takmarka fjölda atburða sem birtast í mánaðaryfirlitinu",
-    "Show weekends" : "Sýna helgar",
-    "Show week numbers" : "Sýna vikunúmer",
-    "Time increments" : "Tímaþrep",
-    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
-    "Default reminder" : "Sjálfgefin áminning",
+    "General" : "Almennt",
+    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
     "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
     "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
-    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
-    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
+    "Enable birthday calendar" : "Virkja fæðingardagatal",
+    "Show tasks in calendar" : "Sýna verkefni í dagatali",
+    "Show weekends" : "Sýna helgar",
+    "Show week numbers" : "Sýna vikunúmer",
+    "Editing" : "Breytingar",
+    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
+    "Default reminder" : "Sjálfgefin áminning",
+    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Appointment schedule successfully created" : "Tókst að útbúa dagskrá stefnumóta",
     "Appointment schedule successfully updated" : "Tókst að uppfæra dagskrá stefnumóta",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} mínúta","{duration} mínútur"],
@@ -415,6 +413,7 @@ OC.L10N.register(
     "Update this occurrence" : "Uppfæra þetta tilviki",
     "Public calendar does not exist" : "Opinbert dagatal er ekki til",
     "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
+    "None" : "Ekkert",
     "Create" : "Búa til",
     "from {formattedDate}" : "frá {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
@@ -475,6 +474,7 @@ OC.L10N.register(
     "Untitled event" : "Ónefndur atburður",
     "Close" : "Loka",
     "Participants" : "Þátttakendur",
+    "Submit" : "Senda inn",
     "Subscribe to {name}" : "Panta áskrift að {name}",
     "Export {name}" : "Flytja út {name}",
     "Show availability" : "Sýna lausa tíma",
@@ -569,6 +569,13 @@ OC.L10N.register(
     "This is an event reminder." : "Þetta er áminning vegna atburðar.",
     "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
     "Appointment not found" : "Stefnumót fannst ekki",
-    "User not found" : "Notandi fannst ekki"
+    "User not found" : "Notandi fannst ekki",
+    "Hidden" : "Falinn",
+    "Automatic ({detected})" : "Sjálfvirkt ({detected})",
+    "Shortcut overview" : "Yfirlit flýtilykla",
+    "Enable simplified editor" : "Virkja einfaldaðan ritil",
+    "Limit the number of events displayed in the monthly view" : "Takmarka fjölda atburða sem birtast í mánaðaryfirlitinu",
+    "Time increments" : "Tímaþrep",
+    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
