@@ -114,7 +114,6 @@ OC.L10N.register(
     "Could not update calendar order." : "カレンダーの順番を更新できません。",
     "Shared calendars" : "共有カレンダー",
     "Deck" : "デッキ",
-    "Hidden" : "非公開",
     "Internal link" : "内部リンク",
     "A private link that can be used with external clients" : "外部クライアントと使用できるプライベートリンク",
     "Copy internal link" : "内部リンクをコピー",
@@ -165,7 +164,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nイベントのインポートに成功しました"],
     "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
     "Automatic" : "自動",
-    "Automatic ({detected})" : "自動 ({detected})",
+    "Automatic ({timezone})" : "自動 ({timezone})",
     "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
     "Timezone" : "タイムゾーン",
     "Navigation" : "ナビゲーション",
@@ -254,6 +253,7 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "会議の準備に役立つことがあれば教えてください。",
     "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
     "Back" : "戻る",
+    "Create a new public conversation" : "公開の会話を作成する",
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
@@ -396,6 +396,7 @@ OC.L10N.register(
     "Yes" : "はい",
     "No" : "いいえ",
     "Maybe" : "たぶん",
+    "None" : "なし",
     "Create" : "作成",
     "from {formattedDate}" : "{formattedDate}から",
     "to {formattedDate}" : "{formattedDate}まで",
@@ -441,6 +442,7 @@ OC.L10N.register(
     "Personal" : "個人",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動的なタイムゾーンの検出により、あなたのタイムゾーンはUTCと判断されました。\nこれはおそらく、あなたのウェブブラウザのセキュリティ対策の結果です。\nカレンダーの設定でタイムゾーンを手動で設定してください。",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "設定されたタイムゾーン ({timezoneId}) が見つかりませんでした。UTCにフォールバックします。\n設定でタイムゾーンを変更して、この問題を報告してください。",
+    "Discard event" : "イベントを破棄",
     "Edit event" : "イベントを編集",
     "Event does not exist" : "イベントは存在しません",
     "Duplicate" : "複製",
@@ -450,6 +452,7 @@ OC.L10N.register(
     "Managing shared access" : "共有アクセスの管理",
     "Deny access" : "アクセスを拒否する",
     "Invite" : "招待状",
+    "Discard changes?" : "変更を破棄しますか？",
     "_User requires access to your file_::_Users require access to your file_" : ["ファイルへのアクセスが必要なユーザ"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
     "Untitled event" : "無題のイベント",
@@ -551,6 +554,8 @@ OC.L10N.register(
     "This is an event reminder." : "これはイベントのリマインダーです。",
     "Appointment not found" : "予定が見つかりません",
     "User not found" : "ユーザーが見つかりません",
+    "Hidden" : "非公開",
+    "Automatic ({detected})" : "自動 ({detected})",
     "Shortcut overview" : "概要",
     "Enable simplified editor" : "簡易エディターを有効にする",
     "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
