@@ -2,7 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Provided email-address is too long" : "Norādītā e-pasta adrese ir pārāk gara",
-    "User-Session unexpectedly expired" : "Lietotāja sesija ir negaidīti beigusies",
+    "User-Session unexpectedly expired" : "Lietotāja sesija negaidīti beidzās",
     "Provided email-address is not valid" : "Norādītā e-pasta adrese nav derīga",
     "%s has published the calendar »%s«" : "%s dalījās ar kalendāru »%s«",
     "Unexpected error sending email. Please contact your administrator." : "E-pasta ziņojuma nosūtīšanas laikā bija neparedzēta kļūda. Lūgums sazināties ar savu pārvaldītāju.",
@@ -106,7 +106,6 @@ OC.L10N.register(
     "Delete permanently" : "Neatgriezeniski izdzēst",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienas","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām"],
     "Could not update calendar order." : "Nevarēja atjaunināt kalendāra pasūtījumu.",
-    "Hidden" : "Paslēpts",
     "Internal link" : "Iekšējā saite",
     "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
     "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
@@ -152,7 +151,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
     "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
     "Automatic" : "Automātisks",
-    "Automatic ({detected})" : "Automātiska ({detected})",
+    "Automatic ({timezone})" : "Automātiski ({timezone})",
     "New setting was not saved successfully." : "Jauna iestatījuma saglabāšana neizdevās.",
     "Timezone" : "Laika josla",
     "Navigation" : "Navigācija",
@@ -343,6 +342,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Varbūt kopīgojums tika izdzēsts, vai arī ir beidzies tā derīgums?",
     "Yes" : "Jā",
     "No" : "Nē",
+    "None" : "Nekas",
     "from {formattedDate}" : "no {formattedDate}",
     "to {formattedDate}" : "līdz {formattedDate}",
     "from {formattedDate} at {formattedTime}" : "no {formattedDate} plkst. {formattedTime}",
@@ -465,6 +465,8 @@ OC.L10N.register(
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
     "User not found" : "Lietotājs nav atrasts",
+    "Hidden" : "Paslēpts",
+    "Automatic ({detected})" : "Automātiska ({detected})",
     "Shortcut overview" : "Īsceļu pārskats",
     "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
     "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
