@@ -114,7 +114,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
     "Shared calendars" : "Delte kalendere",
     "Deck" : "Stokk",
-    "Hidden" : "Skjult",
     "Internal link" : "Intern lenke",
     "A private link that can be used with external clients" : "En privat lenke som kan brukes med eksterne klienter",
     "Copy internal link" : "Kopier intern lenke",
@@ -166,7 +165,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Vellykket importert %n hendelse","Vellykket importert %n hendelser"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importen mislyktes delvis. Importerte {accepted} av {total}. ",
     "Automatic" : "Automatisk",
-    "Automatic ({detected})" : "Automatisk ({detected})",
+    "Automatic ({timezone})" : "Automatisk ({timezone})",
     "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
     "Timezone" : "Tidssone",
     "Navigation" : "Navigasjon",
@@ -397,6 +396,7 @@ OC.L10N.register(
     "Yes" : "Ja",
     "No" : "Nei",
     "Maybe" : "Kanskje",
+    "None" : "Ingen",
     "Create" : "Opprett",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
@@ -552,6 +552,8 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
     "User not found" : "Fant ikke brukeren",
+    "Hidden" : "Skjult",
+    "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Oversikt over snarveier",
     "Enable simplified editor" : "Aktiver forenklet redigering",
     "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
