@@ -94,7 +94,6 @@ OC.L10N.register(
     "Delete permanently" : "Eliminar permanentemente",
     "Could not update calendar order." : "Não foi possível atualizar a ordenação do calendário.",
     "Deck" : "Quadro",
-    "Hidden" : "Escondido",
     "Copy internal link" : "Copiar ligação interna",
     "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
     "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
@@ -131,7 +130,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "A importação foi cancelada pois não foram encontrados ficheiros válidos",
     "Import partially failed. Imported {accepted} out of {total}." : "A importação falhou parcialmente. Importados {accepted} de um total de {total}.",
     "Automatic" : "Automático",
-    "Automatic ({detected})" : "Automático ({detected})",
+    "Automatic ({timezone})" : "Automático ({timezone})",
     "New setting was not saved successfully." : "Erro a gravar a nova configuração.",
     "Navigation" : "Navegação",
     "Previous period" : "Período anterior",
@@ -268,6 +267,7 @@ OC.L10N.register(
     "available" : "disponível",
     "Yes" : "Sim",
     "No" : "Não",
+    "None" : "Nenhum",
     "Create" : "Criar",
     "Pick a date" : "Escolha uma data",
     "Global" : "Global",
@@ -306,6 +306,8 @@ OC.L10N.register(
     "Error while sharing file" : "Erro ao partilhar ficheiro",
     "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
     "User not found" : "Utilizador não encontrado",
+    "Hidden" : "Escondido",
+    "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Visão geral de atalhos",
     "Enable simplified editor" : "Ativar editor simplificado",
     "Time increments" : "Incrementos de tempo",
