@@ -108,7 +108,6 @@ OC.L10N.register(
     "Delete permanently" : "Șterge permanent",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Coșul de gunoi este golit în {numDays} zi","Coșul de gunoi este golit în {numDays} zile","Coșul de gunoi este golit în {numDays} zile"],
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
-    "Hidden" : "Ascuns",
     "Internal link" : "Link intern",
     "A private link that can be used with external clients" : "Link privat ce poate fi folosit cu clienți externi",
     "Copy internal link" : "Copiază linkul intern",
@@ -156,7 +155,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["A fost importat %n eveniment","Au fost importate %n evenimente","Au fost importate %n evenimente"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
     "Automatic" : "Automat",
-    "Automatic ({detected})" : "Automat ({detectat})",
+    "Automatic ({timezone})" : "Automat ({detectat})",
     "New setting was not saved successfully." : "Noile setări nu au fost salvate cu succes.",
     "Navigation" : "Navigare",
     "Previous period" : "Perioada anterioară",
@@ -354,6 +353,7 @@ OC.L10N.register(
     "Remove participant" : "Elimină participant",
     "Yes" : "Da",
     "No" : "Nu",
+    "None" : "Niciuna",
     "Create" : "Crează",
     "from {formattedDate}" : "începând cu {formattedDate}",
     "to {formattedDate}" : "până la {formattedDate}",
@@ -498,6 +498,8 @@ OC.L10N.register(
     "This is an event reminder." : "Acesta este un memento pentru eveniment.",
     "Appointment not found" : "Programarea nu a fost găsită",
     "User not found" : "Utilizatorul nu a fost găsit",
+    "Hidden" : "Ascuns",
+    "Automatic ({detected})" : "Automat ({detectat})",
     "Shortcut overview" : "Prezentare generală a comenzilor rapide",
     "Enable simplified editor" : "Activează editorul simplificat",
     "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
