@@ -112,7 +112,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Ni mogoče posodobiti koledarja",
     "Shared calendars" : "Koledarji v souporabi",
     "Deck" : "Deck",
-    "Hidden" : "Skrito",
     "Internal link" : "Notranja povezava",
     "A private link that can be used with external clients" : "Zasebna povezava, ki se lahko uporablja z zunanjimi odjemalci",
     "Copy internal link" : "Kopiraj krajevno povezavo",
@@ -163,7 +162,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspešno je uvožen %n dogodek.","Uspešno sta uvožena %n dogodka.","Uspešno so uvoženi %n dogodki.","Uspešno je uvoženih %n dogodkov."],
     "Import partially failed. Imported {accepted} out of {total}." : "Uvoz je delno spodletel. Uvoženih je {accepted} od skupno {total}.",
     "Automatic" : "Samodejno",
-    "Automatic ({detected})" : "Samodejno ({detected})",
+    "Automatic ({timezone})" : "Samodejno ({timezone})",
     "New setting was not saved successfully." : "Novih nastavitev ni bilo mogoče shraniti.",
     "Timezone" : "Časovni pas",
     "Navigation" : "Krmarjenje",
@@ -381,6 +380,7 @@ OC.L10N.register(
     "Yes" : "Da",
     "No" : "Ne",
     "Maybe" : "Morda",
+    "None" : "Brez",
     "Create" : "Ustvari",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
@@ -529,6 +529,8 @@ OC.L10N.register(
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
     "User not found" : "Uporabnika ni mogoče najti",
+    "Hidden" : "Skrito",
+    "Automatic ({detected})" : "Samodejno ({detected})",
     "Shortcut overview" : "Pregled tipkovnih bližnjic",
     "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
     "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
