@@ -112,7 +112,6 @@ OC.L10N.register(
     "Could not update calendar order." : "كالېندار تەرتىپىنى يېڭىلىيالمىدى.",
     "Shared calendars" : "ئورتاق كالېندار",
     "Deck" : "پالۋان",
-    "Hidden" : "يۇشۇرۇن",
     "Internal link" : "ئىچكى ئۇلىنىش",
     "A private link that can be used with external clients" : "سىرتقى خېرىدارلار بىلەن ئىشلىتىشكە بولىدىغان شەخسىي ئۇلىنىش",
     "Copy internal link" : "ئىچكى ئۇلىنىشنى كۆچۈرۈڭ",
@@ -161,7 +160,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
     "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {accepted} دىن ئىمپورت قىلىنغان {total} قىلىندى}.",
     "Automatic" : "ئاپتوماتىك",
-    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
+    "Automatic ({timezone})" : "ئاپتوماتىك ({timezone})",
     "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
     "Navigation" : "يول باشلاش",
     "Previous period" : "ئالدىنقى مەزگىل",
@@ -381,6 +380,7 @@ OC.L10N.register(
     "Yes" : "ھەئە",
     "No" : "ياق",
     "Maybe" : "مۇمكىن",
+    "None" : "يوق",
     "Create" : "قۇر",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
@@ -523,6 +523,8 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
     "Appointment not found" : "تەيىنلەنمىدى",
     "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
+    "Hidden" : "يۇشۇرۇن",
+    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
     "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
     "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
     "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
